The Linux Kernel Mailing List
 help / color / mirror / Atom feed
From: Gabor Juhos <j4g8y7@gmail.com>
To: Bjorn Andersson <andersson@kernel.org>,
	 Konrad Dybcio <konradybcio@kernel.org>
Cc: linux-arm-msm@vger.kernel.org, linux-kernel@vger.kernel.org,
	 Gabor Juhos <j4g8y7@gmail.com>
Subject: [PATCH 2/2] soc: qcom: mdt_loader: rename 'firmware' parameter of qcom_mdt_load()
Date: Tue, 11 Nov 2025 08:40:11 +0100	[thread overview]
Message-ID: <20251111-mdt-loader-cleanup-v1-2-71afee094dce@gmail.com> (raw)
In-Reply-To: <20251111-mdt-loader-cleanup-v1-0-71afee094dce@gmail.com>

In the 'mdt_loader.h' header, both the prototype and the inline
version of the qcom_mdt_load() function uses 'fw_name' as name for
the firmware name parameter. Additionally, the other qcom_mdt_*
functions are using that as well.

For consistency, rename the 'firmware' parameter in the implementation
of the qcom_mdt_load() to 'fw_name' and update the function accordingly.

No functional changes.

Signed-off-by: Gabor Juhos <j4g8y7@gmail.com>
---
 drivers/soc/qcom/mdt_loader.c | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/drivers/soc/qcom/mdt_loader.c b/drivers/soc/qcom/mdt_loader.c
index a68a22d174200f5f3bfced6678e5bffa0016ca14..c239107cb93017eca6f6b00876e2c10706a3e50d 100644
--- a/drivers/soc/qcom/mdt_loader.c
+++ b/drivers/soc/qcom/mdt_loader.c
@@ -453,7 +453,7 @@ EXPORT_SYMBOL_GPL(qcom_mdt_load_no_init);
  * qcom_mdt_load() - load the firmware which header is loaded as fw
  * @dev:	device handle to associate resources with
  * @fw:		firmware object for the mdt file
  * @firmware:	name of the firmware, for construction of segment file names
  * @pas_id:	PAS identifier
  * @mem_region:	allocated memory region to load firmware into
  * @mem_phys:	physical address of allocated memory region
@@ -463,17 +463,17 @@ EXPORT_SYMBOL_GPL(qcom_mdt_load_no_init);
  * Returns 0 on success, negative errno otherwise.
  */
 int qcom_mdt_load(struct device *dev, const struct firmware *fw,
-		  const char *firmware, int pas_id, void *mem_region,
+		  const char *fw_name, int pas_id, void *mem_region,
 		  phys_addr_t mem_phys, size_t mem_size,
 		  phys_addr_t *reloc_base)
 {
 	int ret;
 
-	ret = qcom_mdt_pas_init(dev, fw, firmware, pas_id, mem_phys, NULL);
+	ret = qcom_mdt_pas_init(dev, fw, fw_name, pas_id, mem_phys, NULL);
 	if (ret)
 		return ret;
 
-	return qcom_mdt_load_no_init(dev, fw, firmware, mem_region, mem_phys,
+	return qcom_mdt_load_no_init(dev, fw, fw_name, mem_region, mem_phys,
 				     mem_size, reloc_base);
 }
 EXPORT_SYMBOL_GPL(qcom_mdt_load);
@@ -453,7 +453,7 @@ EXPORT_SYMBOL_GPL(qcom_mdt_load_no_init);
  * @dev:	device handle to associate resources with
  * @fw:		firmware object for the mdt file
- * @firmware:	name of the firmware, for construction of segment file names
+ * @fw_name:	name of the firmware, for construction of segment file names
  * @pas_id:	PAS identifier
  * @mem_region:	allocated memory region to load firmware into

-- 
2.51.1


  parent reply	other threads:[~2025-11-11  7:40 UTC|newest]

Thread overview: 6+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2025-11-11  7:40 [PATCH 0/2] soc: qcom: mdt_loader: minor cleanups Gabor Juhos
2025-11-11  7:40 ` [PATCH 1/2] soc: qcom: mdt_loader: merge __qcom_mdt_load() and qcom_mdt_load_no_init() Gabor Juhos
2025-11-11 10:09   ` Dmitry Baryshkov
2025-11-11  7:40 ` Gabor Juhos [this message]
2025-11-11 10:10   ` [PATCH 2/2] soc: qcom: mdt_loader: rename 'firmware' parameter of qcom_mdt_load() Dmitry Baryshkov
2025-11-14  0:18 ` [PATCH 0/2] soc: qcom: mdt_loader: minor cleanups Bjorn Andersson

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20251111-mdt-loader-cleanup-v1-2-71afee094dce@gmail.com \
    --to=j4g8y7@gmail.com \
    --cc=andersson@kernel.org \
    --cc=konradybcio@kernel.org \
    --cc=linux-arm-msm@vger.kernel.org \
    --cc=linux-kernel@vger.kernel.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox